• v1.11 7a9da11d8b

    v1.11 Stable

    archiver-bot released this 2020-11-26 03:08:07 -06:00 | 293 commits to master since this release

    Maintenance release.

    Release highlights:

    • Add xml_node::remove_attributes and xml_node::remove_children
    • Add a way to customize floating point precision via xml_attribute::set and xml_text::set overloads
    • XPath parser now limits recursion depth which prevents stack overflow on malicious queries
    • Exported CMake target name changed to pugixml::pugixml; see subsequent patch releases

    Read full changelog

    Downloads
  • v1.10 3c59df555b

    v1.10 Stable

    archiver-bot released this 2019-09-11 23:51:02 -05:00 | 357 commits to master since this release

    Maintenance release.

    Release highlights:

    • XPath union operation now is ~2x faster to compute and results in a stable order that doesn't depend on pointer order
    • Add format_skip_control_chars formatting flag to skip non-printable ASCII characters
    • Add format_attribute_single_quote formatting flag to use single quotes for attribute values
    • Add Visual Studio .natvis files to improve debugging experience

    Read full changelog

    Downloads
  • v1.9 8436f2a69b

    v1.9 Stable

    archiver-bot released this 2018-04-04 09:53:16 -05:00 | 425 commits to master since this release

    Maintenance release.

    Release highlights:

    • Added move semantics support for xml_document
    • XPath parser no longer relies on exceptional control flow/longjmp in absence of exceptions
      • xpath_exception is still used to communicate errors when exceptions are enabled
    • Fix compilation issues for some custom GCC installations
    • Fix compilation warnings for GCC 7.3/8

    Read full changelog

    Downloads
  • v1.8.1 d2deb420bc

    v1.8.1 Stable

    archiver-bot released this 2016-11-27 14:09:12 -06:00 | 606 commits to master since this release

    This is a re-release of v1.8 with fixed timestamps for files in .tar.gz

    Downloads
  • v1.8 91bf70231a

    v1.8 Stable

    archiver-bot released this 2016-11-24 02:23:19 -06:00 | 607 commits to master since this release

    Maintenance release.

    Release highlights:

    • Added parse_embed_pcdata parsing mode to reduce memory consumption for some documents
    • Added Latin-1 auto-detection support
    • When printing empty elements, a space is no longer added before / in format_raw mode
    • Fix compilation issues for Borland C++ 5.4 and some distributions of MinGW 3.8

    Read full changelog

    Downloads
  • v1.7 0c8024920f

    v1.7 Stable

    archiver-bot released this 2015-10-18 22:13:52 -05:00 | 715 commits to master since this release

    Major release, featuring performance and memory improvements along with some new features.

    Release highlights:

    • Introduced a new compact tree storage mode that takes significantly less memory (2-5x smaller DOM) at some performance cost
    • New integer parsing/formatting implementation (3-5x faster at getting/setting integers)
    • Added format_indent_attributes that makes the resulting XML friendlier to line diff/merge tools
    • Fix Clang 3.7 crashes in out-of-memory cases (C++ DR 1748)

    Read full changelog

    Downloads
  • v1.6 9b8553bf4b

    v1.6 Stable

    archiver-bot released this 2015-04-10 22:49:47 -05:00 | 917 commits to master since this release

    Maintenance release focused on bug fixes.

    Release highlights:

    • Fixed translate and normalize-space XPath functions to no longer return internal NUL characters
    • Fixed buffer overrun on malformed comments inside DOCTYPE sections
    • Attribute/text values now use more digits when printing floating point numbers to guarantee round-tripping.

    Read full changelog

    Downloads
  • v1.5 ff16dbdd4c

    v1.5 Stable

    archiver-bot released this 2014-12-13 22:34:10 -06:00 | 987 commits to master since this release

    Major release focused on performance improvements that also has some new features and compatibility improvements.

    Release highlights:

    • Implemented efficient moving of nodes within the same document
    • Optimized parsing (10-40% faster with clang/GCC, 10% faster with MSVC)
    • Optimized node copying (stackless, shares string contents where possible, up to 3x faster overall)
    • Optimized node output (stackless, up to 60% faster)
    • Optimized XPath evaluation (XPathMark suite is 100x faster; some commonly used queries are 4x faster)

    Read full changelog

    Downloads
  • v1.4 9f92eeba44

    v1.4 Stable

    archiver-bot released this 2014-02-28 00:01:23 -06:00 | 1117 commits to master since this release

    Major release, featuring various new features, bug fixes and compatibility improvements.

    Specification changes:

    • Documents without element nodes are now rejected with status_no_document_element error, unless parse_fragment option is used

    Release highlights:

    • More parsing options (parse_fragment flag to parse XML document fragments, parse_trim_pcdata flag to remove leading/trailing whitespace);
    • Better integer support for attribute and text nodes (long long types and hexadecimal conversion);
    • More stack-efficient XPath compilation and evaluation;

    Read full changelog

    Downloads
  • v1.2 a9a537ad40

    v1.2 Stable

    archiver-bot released this 2012-05-02 10:38:09 -05:00 | 1191 commits to master since this release

    Major release, featuring header-only mode, various interface enhancements (i.e. PCDATA manipulation and C++11 iteration), many other features and compatibility improvements.

    Downloads